@@ -27,6 +27,7 @@
 #include <QFileDialog>
 #include <QTemporaryFile>
 #include <QTimer>
+#include <QElapsedTimer>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -135,7 +136,11 @@ void Archiver::setKeptBackups(int num)
 void Archiver::setFilter(const QString &filter)
 {
   filters.clear();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
   QStringList list = filter.split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+  QStringList list = filter.split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
   foreach (const QString &str, list)
     filters.append(QRegExp(str, Qt::CaseSensitive, QRegExp::Wildcard));
 }
@@ -158,7 +163,11 @@ QString Archiver::getFilter() const
 void Archiver::setDirFilter(const QString &filter)
 {
   dirFilters.clear();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
   QStringList list = filter.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#else
+  QStringList list = filter.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#endif
   foreach (const QString &str, list)
   {
     QString expr = str.trimmed();
@@ -387,32 +396,32 @@ bool Archiver::saveProfile(const QString &fileName, const QStringList &includes,
 
   QTextStream stream(&file);
 
-  stream << "M " << targetURL.toString(QUrl::PreferLocalFile) << endl;
-  stream << "P " << getFilePrefix() << endl;
-  stream << "S " << getMaxSliceMBs() << endl;
-  stream << "R " << getKeptBackups() << endl;
-  stream << "F " << getFullBackupInterval() << endl;
+  stream << "M " << targetURL.toString(QUrl::PreferLocalFile) << QLatin1Char('\n');
+  stream << "P " << getFilePrefix() << QLatin1Char('\n');
+  stream << "S " << getMaxSliceMBs() << QLatin1Char('\n');
+  stream << "R " << getKeptBackups() << QLatin1Char('\n');
+  stream << "F " << getFullBackupInterval() << QLatin1Char('\n');
 
   if ( getLastFullBackup().isValid() )
-    stream << "L " << getLastFullBackup().toString(Qt::ISODate) << endl;
+    stream << "L " << getLastFullBackup().toString(Qt::ISODate) << QLatin1Char('\n');
 
   if ( getLastBackup().isValid() )
-    stream << "B " << getLastBackup().toString(Qt::ISODate) << endl;
+    stream << "B " << getLastBackup().toString(Qt::ISODate) << QLatin1Char('\n');
 
-  stream << "C " << static_cast<int>(getMediaNeedsChange()) << endl;
-  stream << "Z " << static_cast<int>(getCompressFiles()) << endl;
+  stream << "C " << static_cast<int>(getMediaNeedsChange()) << QLatin1Char('\n');
+  stream << "Z " << static_cast<int>(getCompressFiles()) << QLatin1Char('\n');
 
   if ( !filters.isEmpty() )
-    stream << "X " << getFilter() << endl;
+    stream << "X " << getFilter() << QLatin1Char('\n');
 
   foreach (const QRegExp &exp, dirFilters)
-    stream << "x " << exp.pattern() << endl;
+    stream << "x " << exp.pattern() << QLatin1Char('\n');
 
   foreach (const QString &str, includes)
-    stream << "I " << str << endl;
+    stream << "I " << str << QLatin1Char('\n');
 
   foreach (const QString &str, excludes)
-    stream << "E " << str << endl;
+    stream << "E " << str << QLatin1Char('\n');
 
   file.close();
   return true;
@@ -517,7 +526,7 @@ bool Archiver::createArchive(const QStringList &includes, const QStringList &exc
     QString entry = *it;
 
     if ( (entry.length() > 1) && entry.endsWith(QLatin1Char('/')) )
-      entry.truncate(entry.length() - 1);
+      entry.chop(1);
 
     QFileInfo info(entry);
 
@@ -879,8 +888,8 @@ void Archiver::receivedOutput()
   QByteArray buffer = proc->readAllStandardOutput();
 
   QString msg = QString::fromUtf8(buffer);
-  if ( msg.endsWith(QLatin1String("\n")) )
-    msg.truncate(msg.length() - 1);
+  if ( msg.endsWith(QLatin1Char('\n')) )
+    msg.chop(1);
 
   emit warning(msg);
 }
@@ -915,7 +924,7 @@ bool Archiver::getNextSlice()
     QString prefix = filePrefix.isEmpty() ? QStringLiteral("backup") : filePrefix;
 
     if ( targetURL.isLocalFile() )
-      baseName = targetURL.path() + QStringLiteral("/") + prefix + QDateTime::currentDateTime().toString(QStringLiteral("_yyyy.MM.dd-hh.mm.ss"));
+      baseName = targetURL.path() + QLatin1Char('/') + prefix + QDateTime::currentDateTime().toString(QLatin1String("_yyyy.MM.dd-hh.mm.ss"));
     else
       baseName = QDir::tempPath() + QLatin1Char('/') + prefix + QDateTime::currentDateTime().toString(QStringLiteral("_yyyy.MM.dd-hh.mm.ss"));
   }
@@ -1024,7 +1033,7 @@ void Archiver::addDirFiles(QDir &dir)
   if ( cancelled ) return;
 
   if ( ! archive->writeDir(QStringLiteral(".") + absolutePath, dirInfo.owner(), dirInfo.group(),
-                           status.st_mode, dirInfo.lastRead(), dirInfo.lastModified(), dirInfo.created()) )
+                           status.st_mode, dirInfo.lastRead(), dirInfo.lastModified(), dirInfo.birthTime()) )
   {
     emit warning(i18n("Could not write directory '%1' to archive.\n"
                       "Maybe the medium is full.", absolutePath));
@@ -1158,7 +1167,7 @@ void Archiver::addFile(const QFileInfo &info)
 
       if ( ! archive->prepareWriting(QStringLiteral(".") + info.absoluteFilePath() + ext,
                                      info.owner(), info.group(), tmpFile.size(),
-                                     status.st_mode, info.lastRead(), info.lastModified(), info.created()) )
+                                     status.st_mode, info.lastRead(), info.lastModified(), info.birthTime()) )
       {
         emitArchiveError();
         cancel();
@@ -1251,7 +1260,7 @@ Archiver::AddFileStatus Archiver::addLocalFile(const QFileInfo &info)
 
   if ( ! archive->prepareWriting(QStringLiteral(".") + info.absoluteFilePath(),
                                  info.owner(), info.group(), info.size(),
-                                 sourceStat.st_mode, info.lastRead(), info.lastModified(), info.created()) )
+                                 sourceStat.st_mode, info.lastRead(), info.lastModified(), info.birthTime()) )
   {
     emitArchiveError();
     return Error;
@@ -1261,7 +1270,7 @@ Archiver::AddFileStatus Archiver::addLocalFile(const QFileInfo &info)
   static char buffer[BUFFER_SIZE];
   qint64 len;
   int count = 0, progress;
-  QTime timer;
+  QElapsedTimer timer;
   timer.start();
   bool msgShown = false;
   qint64 written = 0;
@@ -1368,7 +1377,7 @@ bool Archiver::compressFile(const QString &origName, QFile &comprFile)
     static char buffer[BUFFER_SIZE];
     qint64 len;
     int count = 0, progress;
-    QTime timer;
+    QElapsedTimer timer;
     timer.start();
     bool msgShown = false;
 
